==> ejc-businessplan-impl-3.0.0-20220722.023953-100-sources.jar: com/ejianc/business/busniessplan/bean/CountersignaturedetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 商务策划会签子表
 *
 * @author generator
 *
 */
 @TableName("ejc_businessplan_countersignaturedetail")
public class CountersignaturedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="link_bill_id")
    private Long linkBillId; // 关联单据id
    @TableField(value="link_bill_name")
    private String linkBillName; // 关联单据名称
    @TableField(value="link_bill_code")
    private String linkBillCode; // 关联单据编码




    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 关联单据id
     */
    public Long getLinkBillId() {
        return linkBillId;
    }

    /**
     * 关联单据id
     */
    public void setLinkBillId(Long linkBillId) {
        this.linkBillId = linkBillId;
    }
    /**
     * 关联单据名称
     */
    public String getLinkBillName() {
        return linkBillName;
    }

    /**
     * 关联单据名称
     */
    public void setLinkBillName(String linkBillName) {
        this.linkBillName = linkBillName;
    }
    /**
     * 关联单据编码
     */
    public String getLinkBillCode() {
        return linkBillCode;
    }

    /**
     * 关联单据编码
     */
    public void setLinkBillCode(String linkBillCode) {
        this.linkBillCode = linkBillCode;
    }

}

==> ejc-businessplan-impl-3.0.0-20251020.073959-225-sources.jar: com/ejianc/business/busniessplan/bean/CountersignaturedetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 商务策划会签子表
 *
 * @author generator
 *
 */
 @TableName("ejc_businessplan_countersignaturedetail")
public class CountersignaturedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="link_bill_id")
    private Long linkBillId; // 关联单据id
    @TableField(value="link_bill_name")
    private String linkBillName; // 关联单据名称
    @TableField(value="link_bill_code")
    private String linkBillCode; // 关联单据编码
    @TableField(value="change_status")
    private Integer changeStatus; // 是否存在变更

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 关联单据id
     */
    public Long getLinkBillId() {
        return linkBillId;
    }

    /**
     * 关联单据id
     */
    public void setLinkBillId(Long linkBillId) {
        this.linkBillId = linkBillId;
    }
    /**
     * 关联单据名称
     */
    public String getLinkBillName() {
        return linkBillName;
    }

    /**
     * 关联单据名称
     */
    public void setLinkBillName(String linkBillName) {
        this.linkBillName = linkBillName;
    }
    /**
     * 关联单据编码
     */
    public String getLinkBillCode() {
        return linkBillCode;
    }

    /**
     * 关联单据编码
     */
    public void setLinkBillCode(String linkBillCode) {
        this.linkBillCode = linkBillCode;
    }

}
